#
# spec file for package python-AnyQt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%define pysidepython python3
%else
%{?sle15_python_module_pythons}
%define pysidepython %pythons
%endif
%define pysidepython_sitelib %{expand:%%%{pysidepython}_sitelib}
%define pysidepython_version %{expand:%%%{pysidepython}_version}

Name:           python-AnyQt
Version:        0.2.0
Release:        4.2
Summary:        PyQt4/PyQt5 compatibility layer
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/ales-erjavec/anyqt
Source:         https://github.com/ales-erjavec/anyqt/archive/refs/tags/%{version}.tar.gz#/AnyQt-%{version}-gh.tar.gz
# PATCH-FIX-SLE do-not-test-pyqt4.patch alarrosa@suse.com -- Do not try testing the PyQt4 api
Patch0:         do-not-test-pyqt4.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-qt5
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module qt5}
BuildRequires:  %{pysidepython}-pyside2
BuildRequires:  %{python_module PyQt6}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module qtwebengine-qt5}
# /SECTION
%python_subpackages

%description
PyQt4/PyQt5 compatibility layer.

Features include:

* At the top level, AnyQt exports a Qt5 compatible module namespace along with
  some minimal renames to better support portability between different
  versions.
* The "QT_API" environment variable controls which Qt API/backend is used.
* The API can be chosen/forced programmatically (as long as no
  PyQt4/PyQt5/PySide was already imported).
* An optional compatibility import hook that denies imports from
  conflicting Qt APIs, or intercepts and fakes Qt4 API imports to use a Qt5
  compatible API (some monkey patching is involved).

%prep
%autosetup -p1 -n anyqt-%{version}

rm AnyQt/QtWinExtras.py
rm AnyQt/QtMacExtras.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
for q in pyqt5 pyqt6; do
  export QT_API=$q
  %pytest --ignore test/
done
# not ready for pyside6 yet
for q in pyside2; do
  export QT_API=$q
  export PYTHONPATH=%{buildroot}%{pysidepython_sitelib}
  pytest-%{pysidepython_version} --ignore test/
done
# this doesn't return error codes, check output manually
unset QT_API
%python_exec test/test_import.py

%files %{python_files}
%doc README.txt
%license LICENSE.txt
%{python_sitelib}/AnyQt
%{python_sitelib}/AnyQt-%{version}.dist-info

%changelog
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Enable SLE15 python module
* Wed Jun 21 2023 Ben Greiner <code@bnavigator.de>
- Use PEP517
- Activate more tests with more APIs
* Thu Sep 15 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 0.2.0
  * Bump version: 0.2.0rc1 → 0.2.0
  * Bump version: 0.1.1 → 0.2.0rc1
  * CI: Add libxcb-shape0 to list of linux system packages
  * CI: Add PySide2 to CI tests
  * PySide2: Fix for PYSIDE-237 bug
  * PySide2: Add compatible QPdfWriter.setPageSize overload
  * test_qaction_set_menu: PySide2 compatibility
  * QtCore: Expose cast/wrap/unwrapinstance, ...
  * QtCore: Add BoundSignal type
  * PySide2: alias missing exec methods
  * PySide2: Add missing QActionEvent.{action,before}
  * PySide2: Import missing pieces
  * pyside2: drawPixmapFragments compatibility
  * pyside2: QtTest compatibility
  * pyside2: QSettings compatibility
* Tue Aug  2 2022 Otto Hollmann <otto.hollmann@suse.com>
- update to 0.1.1
  * importhooks: Fix deprecation warnings `find_module` and `load_module` are deprecated.
- from version 0.1.0
  * Update imports of QWebEngineCore components for Qt6
  * Add tests
  * Add forward compatible QTextEdit.setTabStopDistance, ...
  * Qt5: Add forward compatible QAbstractItem.itemDelegateForIndex method
  * Add forward compatible QAbstractItemView.initViewItemOption
  * Make available enum members in type when not present
  * PyQt6: Add ctypes QAction.menu/setMenut
  * Add QLibraryInfo.path if not present
  * PyQt6: Add back obsolete accessors to QWheelEvent
  * PyQt6: Add back obsolete accessors to QDropEvent, QEnterEvent
  * PyQt6: Add back obsolete pos,x, ..., accessors to QMouseEvent
  * PyQt6: Implement QAbstractItemView.viewOptions back compatible method
  * PyQt6: Move QShortcut, QAction imports
  * PyQt6: Move QUndoStack, ... imports
  * PyQt6: Add back some common Enum/Flag type aliases
  * PyQt6: Add QtSvgWidgets stub module
  * Add support for PyQt6
  * Make all members of QFontDatabase static
- updated patch do-not-test-pyqt4.patch
* Mon Mar  7 2022 Dirk Müller <dmueller@suse.com>
- update to 0.0.14
  * Raise a deprecationwarning on qlineedit.getTextMargins
  * QSignalMapper: Add mappedInt/String when not available
  * QComboBox: add a textActivated/Highlighted signal if not present
  * QGroupBox: Add idClicked/Pressed/Released/Toggled when not present
* Fri Aug 13 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.0.13
  * Raise deprecation warning on getContentsMargins
  * Add missing QPdfWriter.setPageSize(QPageSize) overload for PyQt5
  * QtWidgets: Raise a DeprecationWarning on use of QApplication.desktop
  * Raise a DeprecationWarning on use of QFontMetrics(F).width
  * QtGui: Add QFontMetrics.horizontalAdvance when not present
  * QtWidgets: Add QWidget.screen when not present
  * QtGui: Add QGuiApplication.screenAt when not present
- from version 0.0.12
  * QtCore: Add a QT_VERSION_INFO tuple with parsed qVersion
  * Add AnyQt.sip stub
  * QTest: Add qWaitFor where not available
* Mon Jan 25 2021 Markéta Machová <mmachova@suse.com>
- update to 0.0.11
  * QtGui: Make WheelEvent >=PyQt5.12 constructor work <PyQt5.12
* Fri Jan 22 2021 Antonio Larrosa <alarrosa@suse.com>
- Use the upstream provided test
- Add patch to fix tests in Backports/Leap so we don't try testing
  the PyQt4 api since we don't have Qt4 anymore in any case
  (boo#1181294):
  * do-not-test-pyqt4.patch
* Thu Jan 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Stop building python2-AnyQt. There are no user in factory.
* Wed Mar  6 2019 Todd R <toddrme2178@gmail.com>
- qtwebengine is now a separate package
* Tue Dec  4 2018 Jan Engelhardt <jengelh@inai.de>
- Grammar fixes.
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
